
/* width */
::-webkit-scrollbar {
    width: 10px;
  }
  
/* Track */
::-webkit-scrollbar-track {
background: #1e1e1e; 
}

/* Handle */
::-webkit-scrollbar-thumb {
background: #585858; 
}

/* Handle on hover */
::-webkit-scrollbar-thumb:hover {
background: #4f4f4f; 
}