* {
  margin: 0;
  padding: 0;
  -webkit-box-sizing: border-box;
          box-sizing: border-box;
  font-family: Segoe WPC,Segoe UI, Segoe UI Emoji Regular,sans-serif;
  color: #ffffff;
  z-index: 0;
}
html{
  width: 100%;
  height: 100%;
}

body {
  width: 100%;
  height: 100%;
  display: -ms-grid;
  background-color: #1e1e1e;
  overflow: hidden;
  font-size: 13px;
  display: flex;
  justify-content: center;
}

.banner {
  padding: 5px;
  width: 45%;
  height: 60%;
  background-color: #252526;
  box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19);
  position: absolute;
  left: 50%;
  top: 50%;
  -webkit-transform: translate(-50%, -50%);
  transform: translate(-50%, -50%);
  
}

p.heading {
  font-size: 20px;
}

div.tile {
  background-color: #094771;
  width: 80%;
  padding: 1em;
  margin-top: 3em;
  margin-left: auto;
  margin-right: auto;
  cursor: pointer;
}

.tile-text {
  width: 80%;
  margin-top: 3em;
  margin-left: auto;
  margin-right: auto;
}

div.tile:hover {
  box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.2), 0 6px 20px 0 rgba(0, 0, 0, 0.19);
}
input[type="file"] {
    display: none;
}

#start-step-3-file-upload-done {
  color: #587c0c;
  position:absolute;
  font-size: 2em;
  bottom: 1em;
  margin-left: auto;
  margin-right: auto;
  left: 0;
  right: 0;
  text-align: center;
  display: block;
  width: 2em;
  height: 2em;
}

a, a:hover, a:focus, a:active {
  text-decoration: none;
  color: inherit;
}

.windows8 {
	position:absolute;
	font-size: 2em;
	bottom: 1em;
	margin-left: auto;
	margin-right: auto;
	left: 0;
	right: 0;
	text-align: center;
	display: block;
	width: 14px;
	height:14px;

}

.windows8 .wBall {
	position: absolute;
	width: 13px;
	height: 13px;
	opacity: 0;
	transform: rotate(225deg);
		-o-transform: rotate(225deg);
		-ms-transform: rotate(225deg);
		-webkit-transform: rotate(225deg);
		-moz-transform: rotate(225deg);
	animation: orbit 5.4425s infinite;
		-o-animation: orbit 5.4425s infinite;
		-ms-animation: orbit 5.4425s infinite;
		-webkit-animation: orbit 5.4425s infinite;
		-moz-animation: orbit 5.4425s infinite;
}

.windows8 .wBall .wInnerBall{
	position: absolute;
	width: 2px;
	height: 2px;
	background: rgba(255,255,255,0.97);
	left:0px;
	top:0px;
	border-radius: 2px;
}

.windows8 #wBall_1 {
	animation-delay: 1.186s;
		-o-animation-delay: 1.186s;
		-ms-animation-delay: 1.186s;
		-webkit-animation-delay: 1.186s;
		-moz-animation-delay: 1.186s;
}

.windows8 #wBall_2 {
	animation-delay: 0.233s;
		-o-animation-delay: 0.233s;
		-ms-animation-delay: 0.233s;
		-webkit-animation-delay: 0.233s;
		-moz-animation-delay: 0.233s;
}

.windows8 #wBall_3 {
	animation-delay: 0.4765s;
		-o-animation-delay: 0.4765s;
		-ms-animation-delay: 0.4765s;
		-webkit-animation-delay: 0.4765s;
		-moz-animation-delay: 0.4765s;
}

.windows8 #wBall_4 {
	animation-delay: 0.7095s;
		-o-animation-delay: 0.7095s;
		-ms-animation-delay: 0.7095s;
		-webkit-animation-delay: 0.7095s;
		-moz-animation-delay: 0.7095s;
}

.windows8 #wBall_5 {
	animation-delay: 0.953s;
		-o-animation-delay: 0.953s;
		-ms-animation-delay: 0.953s;
		-webkit-animation-delay: 0.953s;
		-moz-animation-delay: 0.953s;
}



@keyframes orbit {
	0% {
		opacity: 1;
		z-index:99;
		transform: rotate(180deg);
		animation-timing-function: ease-out;
	}

	7% {
		opacity: 1;
		transform: rotate(300deg);
		animation-timing-function: linear;
		origin:0%;
	}

	30% {
		opacity: 1;
		transform:rotate(410deg);
		animation-timing-function: ease-in-out;
		origin:7%;
	}

	39% {
		opacity: 1;
		transform: rotate(645deg);
		animation-timing-function: linear;
		origin:30%;
	}

	70% {
		opacity: 1;
		transform: rotate(770deg);
		animation-timing-function: ease-out;
		origin:39%;
	}

	75% {
		opacity: 1;
		transform: rotate(900deg);
		animation-timing-function: ease-out;
		origin:70%;
	}

	76% {
	opacity: 0;
		transform:rotate(900deg);
	}

	100% {
	opacity: 0;
		transform: rotate(900deg);
	}
}

@-o-keyframes orbit {
	0% {
		opacity: 1;
		z-index:99;
		-o-transform: rotate(180deg);
		-o-animation-timing-function: ease-out;
	}

	7% {
		opacity: 1;
		-o-transform: rotate(300deg);
		-o-animation-timing-function: linear;
		-o-origin:0%;
	}

	30% {
		opacity: 1;
		-o-transform:rotate(410deg);
		-o-animation-timing-function: ease-in-out;
		-o-origin:7%;
	}

	39% {
		opacity: 1;
		-o-transform: rotate(645deg);
		-o-animation-timing-function: linear;
		-o-origin:30%;
	}

	70% {
		opacity: 1;
		-o-transform: rotate(770deg);
		-o-animation-timing-function: ease-out;
		-o-origin:39%;
	}

	75% {
		opacity: 1;
		-o-transform: rotate(900deg);
		-o-animation-timing-function: ease-out;
		-o-origin:70%;
	}

	76% {
	opacity: 0;
		-o-transform:rotate(900deg);
	}

	100% {
	opacity: 0;
		-o-transform: rotate(900deg);
	}
}

@-ms-keyframes orbit {
	0% {
		opacity: 1;
		z-index:99;
		-ms-transform: rotate(180deg);
		-ms-animation-timing-function: ease-out;
	}

	7% {
		opacity: 1;
		-ms-transform: rotate(300deg);
		-ms-animation-timing-function: linear;
		-ms-origin:0%;
	}

	30% {
		opacity: 1;
		-ms-transform:rotate(410deg);
		-ms-animation-timing-function: ease-in-out;
		-ms-origin:7%;
	}

	39% {
		opacity: 1;
		-ms-transform: rotate(645deg);
		-ms-animation-timing-function: linear;
		-ms-origin:30%;
	}

	70% {
		opacity: 1;
		-ms-transform: rotate(770deg);
		-ms-animation-timing-function: ease-out;
		-ms-origin:39%;
	}

	75% {
		opacity: 1;
		-ms-transform: rotate(900deg);
		-ms-animation-timing-function: ease-out;
		-ms-origin:70%;
	}

	76% {
	opacity: 0;
		-ms-transform:rotate(900deg);
	}

	100% {
	opacity: 0;
		-ms-transform: rotate(900deg);
	}
}

@-webkit-keyframes orbit {
	0% {
		opacity: 1;
		z-index:99;
		-webkit-transform: rotate(180deg);
		-webkit-animation-timing-function: ease-out;
	}

	7% {
		opacity: 1;
		-webkit-transform: rotate(300deg);
		-webkit-animation-timing-function: linear;
		-webkit-origin:0%;
	}

	30% {
		opacity: 1;
		-webkit-transform:rotate(410deg);
		-webkit-animation-timing-function: ease-in-out;
		-webkit-origin:7%;
	}

	39% {
		opacity: 1;
		-webkit-transform: rotate(645deg);
		-webkit-animation-timing-function: linear;
		-webkit-origin:30%;
	}

	70% {
		opacity: 1;
		-webkit-transform: rotate(770deg);
		-webkit-animation-timing-function: ease-out;
		-webkit-origin:39%;
	}

	75% {
		opacity: 1;
		-webkit-transform: rotate(900deg);
		-webkit-animation-timing-function: ease-out;
		-webkit-origin:70%;
	}

	76% {
	opacity: 0;
		-webkit-transform:rotate(900deg);
	}

	100% {
	opacity: 0;
		-webkit-transform: rotate(900deg);
	}
}

@-moz-keyframes orbit {
	0% {
		opacity: 1;
		z-index:99;
		-moz-transform: rotate(180deg);
		-moz-animation-timing-function: ease-out;
	}

	7% {
		opacity: 1;
		-moz-transform: rotate(300deg);
		-moz-animation-timing-function: linear;
		-moz-origin:0%;
	}

	30% {
		opacity: 1;
		-moz-transform:rotate(410deg);
		-moz-animation-timing-function: ease-in-out;
		-moz-origin:7%;
	}

	39% {
		opacity: 1;
		-moz-transform: rotate(645deg);
		-moz-animation-timing-function: linear;
		-moz-origin:30%;
	}

	70% {
		opacity: 1;
		-moz-transform: rotate(770deg);
		-moz-animation-timing-function: ease-out;
		-moz-origin:39%;
	}

	75% {
		opacity: 1;
		-moz-transform: rotate(900deg);
		-moz-animation-timing-function: ease-out;
		-moz-origin:70%;
	}

	76% {
	opacity: 0;
		-moz-transform:rotate(900deg);
	}

	100% {
	opacity: 0;
		-moz-transform: rotate(900deg);
	}
}