.card {
    display: block;
    border-width: 2px;
    border-style: solid;
    border-color: #1e6ba3;
    margin: 10px;
    padding: 5px;
    font-size: 0.9em;
}

.card-text{
    line-height: 2;
    display: inline;
}

.card-highlighted-text{
    padding-left: 1em !important;
    background-color: #B33030; 
    display: inline; 
    border: 2px solid #B33030; 
    margin: 1px; 
    padding: 1px; 
    border-radius: 5px;
    -webkit-touch-callout: none;
    -webkit-user-select: none;
    -khtml-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    -o-user-select: none;
    user-select: none;
}

.card-highlighted-text-close{
    visibility: hidden;
}
